"""
***************************************************************************
    v_vect_stats.py
    ---------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = "Médéric Ribreux"
__date__ = "March 2016"
__copyright__ = "(C) 2016, Médéric Ribreux"


def processCommand(alg, parameters, context, feedback):
    # Exclude outputs from commands
    alg.processCommand(parameters, context, feedback, True)


def processOutputs(alg, parameters, context, feedback):
    # We need to add the initial vector layer to outputs:
    fileName = alg.parameterAsOutputLayer(parameters, "output", context)
    grassName = alg.exportedLayers["areas"]
    dataType = "auto"
    alg.exportVectorLayer(grassName, fileName, dataType=dataType)



"""
***************************************************************************
    v_net_bridge.py
    ---------------------
    Date                 : December 2015
    Copyright            : (C) 2015 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = "Médéric Ribreux"
__date__ = "December 2015"
__copyright__ = "(C) 2015, Médéric Ribreux"

from .v_net import incorporatePoints, variableOutput


def processCommand(alg, parameters, context, feedback):
    incorporatePoints(alg, parameters, context, feedback)


def processOutputs(alg, parameters, context, feedback):
    idx = alg.parameterAsInt(parameters, "method", context)
    operations = alg.parameterDefinition("method").options()
    operation = operations[idx]

    if operation == "articulation":
        outputParameter = {"output": ["output", "point", 2, True]}
    elif operation == "bridge":
        outputParameter = {"output": ["output", "line", 1, False]}
    variableOutput(alg, outputParameter, parameters, context)



# -*- coding: utf-8 -*-

"""
***************************************************************************
    QtMultimedia.py
    ---------------------
    Date                 : January 2025
    Copyright            : (C) 2025 by Julien Cabieces
    Email                : julien dot cabieces at oslandia dot com
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Julien Cabieces'
__date__ = 'January 2025'
__copyright__ = '(C) 2025, Julien Cabieces'

from PyQt6.QtMultimedia import *



"""
***************************************************************************
    qgsfeature.py
    ---------------------
    Date                 : May 2018
    Copyright            : (C) 2018 by Denis Rouzaud
    Email                : denis@opengis.ch
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""


def _mapping_feature(feature):
    geom = feature.geometry()
    properties = feature.attributeMap()
    return {
        "type": "Feature",
        "properties": properties,
        "geometry": geom.__geo_interface__,
    }



"""
***************************************************************************
    QgisAlgorithmTests2.py
    ---------------------
    Date                 : January 2016
    Copyright            : (C) 2016 by Matthias Kuhn
    Email                : matthias@opengis.ch
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = "Matthias Kuhn"
__date__ = "January 2016"
__copyright__ = "(C) 2016, Matthias Kuhn"

import os
import shutil
import unittest

import AlgorithmsTestBase
import nose2
from qgis.analysis import QgsNativeAlgorithms
from qgis.core import QgsApplication, QgsProcessingException
from qgis.testing import QgisTestCase, start_app

from processing.core.ProcessingConfig import ProcessingConfig
from processing.modeler.ModelerUtils import ModelerUtils


class TestQgisAlgorithms4(QgisTestCase, AlgorithmsTestBase.AlgorithmsTest):
    @classmethod
    def setUpClass(cls):
        start_app()
        from processing.core.Processing import Processing

        Processing.initialize()

        # change the model provider folder so that it looks in the test directory for models
        ProcessingConfig.setSettingValue(
            ModelerUtils.MODELS_FOLDER,
            os.path.join(os.path.dirname(__file__), "models"),
        )
        for p in QgsApplication.processingRegistry().providers():
            if p.id() == "model":
                p.refreshAlgorithms()

        cls.cleanup_paths = []
        cls.in_place_layers = {}
        cls.vector_layer_params = {}
        cls._original_models_folder = ProcessingConfig.getSetting(
            ModelerUtils.MODELS_FOLDER
        )

    @classmethod
    def tearDownClass(cls):
        from processing.core.Processing import Processing

        Processing.deinitialize()
        for path in cls.cleanup_paths:
            shutil.rmtree(path)
        ProcessingConfig.setSettingValue(
            ModelerUtils.MODELS_FOLDER, cls._original_models_folder
        )

    def definition_file(self):
        return "qgis_algorithm_tests4.yaml"


if __name__ == "__main__":
    nose2.main()
